@@ -16,7 +16,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
  * 02111-1307, USA.
  */
-
+#undef GTK_DISABLE_DEPRECATED
 #ifdef USE_GUCHARMAP
 #include <gucharmap/gucharmap.h>
 #endif
@@ -212,7 +212,7 @@ void XAP_UnixDialog_Insert_Symbol::event_Insert(void)
 #else
 		UT_ASSERT(m_pListener);
 		const char * symfont = gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(m_fontcombo)->entry));
-		m_Inserted_Symbol = GUCHARMAP_CHARMAP(m_SymbolMap)->chartable->active_char;
+		m_Inserted_Symbol = gucharmap_table_get_active_character(gucharmap_charmap_get_chartable(GUCHARMAP_CHARMAP(m_SymbolMap)));
         m_pListener->setView(getActiveFrame()->getCurrentView());
 		m_pListener->insertSymbol(m_Inserted_Symbol, const_cast<char*>(symfont));
 #endif
