@@ -185,8 +185,6 @@ public:
 	void            shuffleEmbeddedIfNeeded(fl_BlockLayout * pBlock, UT_uint32 blockOffset);
 
 	UT_sint32       getHeightOfBlock(void);
-	fl_BlockLayout* getNextBlockInDocument(void) const;
-	fl_BlockLayout* getPrevBlockInDocument(void) const;
 	fp_Line *       findLineWithFootnotePID(UT_uint32 pid);
 	UT_sint32 getMaxNonBreakableRun(void);
 
@@ -275,7 +273,7 @@ public:
 	void setHdrFtr(void) { m_bIsHdrFtr = true;}
 	void clearHdrFtr(void) { m_bIsHdrFtr = false;}
 
-	void checkSpelling(void);
+	bool checkSpelling(void);
 	void debugFlashing(void);
 	bool	findNextTabStop(UT_sint32 iStartX, UT_sint32 iMaxX,
 							UT_sint32& iPosition, eTabType& iType,
