@@ -1637,14 +1637,16 @@ void
 FL_DocLayout::_toggleAutoSpell(bool bSpell)
 {
 	bool bOldAutoSpell = getAutoSpellCheck();
-
+	UT_DEBUGMSG(("_toggleAutoSpell %d \n",bSpell));
 	// Add reason to background checker
 	if (bSpell)
 	{
+		UT_DEBUGMSG(("Adding Auto SpellCheck  \n"));
 		addBackgroundCheckReason(bgcrSpelling);
 	}
 	else
 	{
+		UT_DEBUGMSG(("Removing Auto SpellCheck  \n"));
 		removeBackgroundCheckReason(bgcrSpelling);
 	}
 
@@ -1653,9 +1655,10 @@ FL_DocLayout::_toggleAutoSpell(bool bSpell)
 
 	if (bSpell)
 	{
+		UT_DEBUGMSG(("Rechecking spelling in blocks \n"));
 		// When enabling, recheck the whole document
 		fl_DocSectionLayout * pSL = getFirstSection();
-		while (pSL)
+		if(pSL)
 		{
 			fl_ContainerLayout* b = pSL->getFirstLayout();
 			while (b)
@@ -1663,17 +1666,23 @@ FL_DocLayout::_toggleAutoSpell(bool bSpell)
 				// TODO: just check and remove matching squiggles
 				// for now, destructively recheck the whole thing
 				if(b->getContainerType() == FL_CONTAINER_BLOCK)
+				{
+					UT_DEBUGMSG(("Add block  %x for spellcheck \n",b));
 					queueBlockForBackgroundCheck(bgcrSpelling, static_cast<fl_BlockLayout *>(b));
-				b = b->getNext();
+					b = static_cast<fl_BlockLayout *>(b)->getNextBlockInDocument();
+				}
+				else
+				{
+					b = b->getNext();
+				}
 			}
-			pSL = static_cast<fl_DocSectionLayout *>(pSL->getNext());
 		}
 	}
 	else
 	{
 		// Disabling, so remove the squiggles too
 		fl_DocSectionLayout * pSL = getFirstSection();
-		while (pSL)
+		if(pSL)
 		{
 			fl_ContainerLayout* b = pSL->getFirstLayout();
 			while (b)
@@ -1682,10 +1691,13 @@ FL_DocLayout::_toggleAutoSpell(bool bSpell)
 				{
 					static_cast<fl_BlockLayout *>(b)->removeBackgroundCheckReason(bgcrSpelling);
 					static_cast<fl_BlockLayout *>(b)->getSquiggles()->deleteAll();
+					b = static_cast<fl_BlockLayout *>(b)->getNextBlockInDocument();
+				}
+				else
+				{
+					b = b->getNext();
 				}
-				b = b->getNext();
 			}
-			pSL = static_cast<fl_DocSectionLayout *>(pSL->getNext());
 		}
 		if (bOldAutoSpell)
 		{
@@ -1789,37 +1801,54 @@ FL_DocLayout::_backgroundCheck(UT_Worker * pWorker)
 			// don't define meaning for most of the bits, but it's
 			// small effort compared to all that squiggle stuff that
 			// goes on for the spelling stuff.
-			for (UT_uint32 bitdex = 0;
-				 bitdex < 8*sizeof(pB->m_uBackgroundCheckReasons);
-				 bitdex++)
+			if(pB->getContainerType() == FL_CONTAINER_BLOCK)
 			{
-				UT_uint32 mask;
-				mask = (1 << bitdex);
-				if (pB->hasBackgroundCheckReason(mask))
+				for (UT_uint32 bitdex = 0;
+					 bitdex < 8*sizeof(pB->m_uBackgroundCheckReasons);
+					 bitdex++)
 				{
+					UT_uint32 mask;
+					mask = (1 << bitdex);
+					if (pB->hasBackgroundCheckReason(mask))
+					{
 					// Note that we remove this reason from queue
 					// before checking it (otherwise asserts could
 					// trigger redundant recursive calls)
-					pB->removeBackgroundCheckReason(mask);
-					switch (mask)
-					{
-					case bgcrNone:
-						break;
-					case bgcrDebugFlash:
-						pB->debugFlashing();
-						break;
-					case bgcrSpelling:
-						pB->checkSpelling();
-						break;
-					case bgcrSmartQuotes:
-					default:
-						break;
+						switch (mask)
+						{
+						case bgcrNone:
+							pB->removeBackgroundCheckReason(mask);
+							break;
+						case bgcrDebugFlash:
+							pB->debugFlashing();
+							pB->removeBackgroundCheckReason(mask);
+							break;
+						case bgcrSpelling:
+						{
+							xxx_UT_DEBUGMSG(("Spelling checking block %x directly \n",pB));
+							bool b = pB->checkSpelling();
+							if(b)
+							{
+								pB->removeBackgroundCheckReason(mask);
+							}
+							break;
+						}
+						case bgcrSmartQuotes:
+						default:
+							pB->removeBackgroundCheckReason(mask);
+							break;
+						}
 					}
 				}
 			}
 			// Delete block from queue if there are no more reasons
 			// for checking it.
-			if (!pB->m_uBackgroundCheckReasons)
+			if(pB->getContainerType() != FL_CONTAINER_BLOCK)
+			{
+				vecToCheck->deleteNthItem(0);
+				i--;
+			}
+			else if (!pB->m_uBackgroundCheckReasons)
 			{
 				vecToCheck->deleteNthItem(0);
 				i--;
@@ -2357,7 +2386,7 @@ void FL_DocLayout::recheckIgnoredWords()
 {
 	// recheck the whole doc
 	fl_DocSectionLayout * pSL = getFirstSection();
-	while (pSL)
+	if(pSL)
 	{
 		fl_ContainerLayout* b = pSL->getFirstLayout();
 		while (b)
@@ -2365,10 +2394,13 @@ void FL_DocLayout::recheckIgnoredWords()
 			if(b->getContainerType() == FL_CONTAINER_BLOCK)
 			{
 				static_cast<fl_BlockLayout *>(b)->recheckIgnoredWords();
+				b = static_cast<fl_BlockLayout *>(b)->getNextBlockInDocument();
+			}
+			else
+			{
+				b = b->getNext();
 			}
-			b = b->getNext();
 		}
-		pSL = static_cast<fl_DocSectionLayout *>(pSL->getNext());
 	}
 }
 
@@ -2855,7 +2887,7 @@ void FL_DocLayout::considerSmartQuoteCandidateAt(fl_BlockLayout *block, UT_uint3
 				do
 				{
 					last = r;
-				} while ((r = r->getNext()));  // assignment
+				} while ((r = r->getNextRun()));  // assignment
 				if (last  &&  (FPRUN_TEXT == last->getType())  &&  last->getLength() > 0)
 				{
 					fp_Line *blocks_line, *lasts_line;
@@ -2887,7 +2919,7 @@ void FL_DocLayout::considerSmartQuoteCandidateAt(fl_BlockLayout *block, UT_uint3
 		{
 			// candidate was the last character in a block, so see
 			// what's at the beginning of the next block, if any
-			fl_BlockLayout *ob = static_cast<fl_BlockLayout *>(block->getNext());
+			fl_BlockLayout *ob = static_cast<fl_BlockLayout *>(block->getNextInDocument());
 			if (ob)
 			{
 				fp_Run *r = ob->getFirstRun();
