@@ -338,6 +338,8 @@ public:
 										PT_DocPosition& pos,
 										bool& bBOL, bool& bEOL);
 	virtual fp_Page *   getPage(void);
+	fp_Line *           getFirstLineInColumn(fp_Column * pCol);
+	fp_Line *           getLastLineInColumn(fp_Column * pCol);
 	void				layout(void);
 	virtual void        setY(UT_sint32 iY);
 	virtual UT_sint32   getHeight(void);
